pub struct CreateConfig {
pub _lp_fee_basis_points: u64,
pub _protocol_fee_basis_points: u64,
pub _protocol_fee_recipients: [Pubkey; 8],
pub _coin_creator_fee_basis_points: u64,
}Expand description
Instruction.
Fields
_lp_fee_basis_points: u64_protocol_fee_basis_points: u64_protocol_fee_recipients: [Pubkey; 8]_coin_creator_fee_basis_points: u64Trait Implementations
Sourceimpl BorshDeserialize for CreateConfig
impl BorshDeserialize for CreateConfig
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreateConfig
impl BorshSerialize for CreateConfig
Sourceimpl Discriminator for CreateConfig
impl Discriminator for CreateConfig
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for CreateConfig
impl InstructionData for CreateConfig