pub struct CreatePool {
pub _index: u16,
pub _base_amount_in: u64,
pub _quote_amount_in: u64,
pub _coin_creator: Pubkey,
}Expand description
Instruction.
Fields
_index: u16_base_amount_in: u64_quote_amount_in: u64_coin_creator: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for CreatePool
impl BorshDeserialize for CreatePool
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreatePool
impl BorshSerialize for CreatePool
Sourceimpl Discriminator for CreatePool
impl Discriminator for CreatePool
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for CreatePool
impl InstructionData for CreatePool